@@ -22,6 +22,7 @@ import org.gcube.portlets.widgets.ckan2zenodopublisher.client.CkanToZenodoPublis
 import org.gcube.portlets.widgets.ckan2zenodopublisher.server.configuration.ZenodoFieldsDescriptionsReader;
 import org.gcube.portlets.widgets.ckan2zenodopublisher.server.converter.ItemToZenodoConverter;
 import org.gcube.portlets.widgets.ckan2zenodopublisher.shared.CatalogueItem;
+import org.gcube.portlets.widgets.ckan2zenodopublisher.shared.ZenodoError;
 import org.gcube.portlets.widgets.ckan2zenodopublisher.shared.wrapped.ZenodoFile;
 import org.gcube.portlets.widgets.ckan2zenodopublisher.shared.wrapped.ZenodoItem;
 import org.gcube.portlets.widgets.ckan2zenodopublisher.shared.wrapped.ZenodoMetadata;
@@ -120,10 +121,13 @@ public class CkanToZenodoPublisherServiceImpl extends RemoteServiceServlet imple
 			String clientError = String.format("%s", error);
 			throw new Exception(clientError);
 		} catch (ZenodoException e) {
-			String error = "ZenodoException during upload to Zenodo the catalogue item: "+zenodoItem.getName();
+			String error = ZenodoException.class.getName()+" during upload to Zenodo the catalogue item: "+zenodoItem.getName();
 			LOG.error(error, e);
-			String clientError = String.format("%s", e.getRemoteMessage());
-			throw new Exception(clientError);
+			//String clientError = String.format("%s", e.getRemoteMessage());
+			ZenodoError zenodoError = new ZenodoError(e);
+			zenodoError.setRemoteMessage(e.getRemoteMessage());
+			zenodoError.setResponseHTTPCode(e.getResponseHTTPCode());
+			throw zenodoError;
 		} catch (Exception e) {
 			String error = "Error during upload to Zenodo the catalogue item: "+zenodoItem.getName();
 			LOG.error(error, e);
@@ -169,10 +173,13 @@ public class CkanToZenodoPublisherServiceImpl extends RemoteServiceServlet imple
 			return zenodoItem;
 			
 		} catch (ZenodoException e) {
-			String error = ZenodoException.class.getSimpleName()+" on converting the catalogue item with id: "+item.getItemId();
+			String error = ZenodoException.class.getName()+" on converting the catalogue item with id: "+item.getItemId();
 			LOG.error(error, e);
-			String clientError = String.format("%s. %s", error, e.getMessage());
-			throw new Exception(clientError);
+			//String clientError = String.format("%s. %s", error, e.getRemoteMessage());
+			ZenodoError zenodoError = new ZenodoError(e);
+			zenodoError.setRemoteMessage(e.getRemoteMessage());
+			zenodoError.setResponseHTTPCode(e.getResponseHTTPCode());
+			throw zenodoError;
 		
 		} catch (Exception e) {
 			String error = "Error on converting the catalogue item with id: "+item.getItemId();
