@@ -265,6 +265,7 @@ public class ItemToZenodoConverter {
 		zm.setTitle(depositionMetadata.getTitle());
 		zm.setVersion(depositionMetadata.getVersion());
 		zm.setNotes(depositionMetadata.getNotes());
+		
 		return zm;
 	}
 
@@ -446,7 +447,7 @@ public class ItemToZenodoConverter {
 		//upload type
 		SerializableEnum<String> uploadType = metadata.getUpload_type();
 		LOG.debug("Read upload type: "+uploadType);
-		if(uploadType!=null) {
+		if(uploadType!=null && uploadType.getSelectedValues()!=null) {
 			String theUploadTypeValue = uploadType.getSelectedValues().get(0);
 			LOG.debug("Set upload type: "+theUploadTypeValue);
 			depositionMetadata.setUpload_type(UploadType.valueOf(theUploadTypeValue));
@@ -455,36 +456,52 @@ public class ItemToZenodoConverter {
 		//access right
 		SerializableEnum<String> accessRight = metadata.getAccess_right();
 		LOG.debug("Read access type: "+accessRight);
-		if(accessRight!=null) {
-			String theAccessRightValue = accessRight.getSelectedValues().get(0);
-			LOG.debug("Set access right: "+theAccessRightValue);
-			depositionMetadata.setAccess_right(AccessRights.valueOf(theAccessRightValue));
+		if(accessRight!=null && accessRight.getSelectedValues()!=null) {
+			try {
+				String theAccessRightValue = accessRight.getSelectedValues().get(0);
+				LOG.debug("Set access right: "+theAccessRightValue);
+				depositionMetadata.setAccess_right(AccessRights.valueOf(theAccessRightValue));
+			}catch (Exception e) {
+				LOG.warn("Set access right error: ",e);
+			}
 		}
 		
 		//publication type
 		SerializableEnum<String> publicationType = metadata.getPublication_type();
 		LOG.debug("Read publication type: "+publicationType);
-		if(publicationType!=null) {
-			String thePublicationTypeValue = publicationType.getSelectedValues().get(0);
-			LOG.debug("Set publication type: "+thePublicationTypeValue);
-			depositionMetadata.setPublication_type(PublicationType.valueOf(thePublicationTypeValue));
+		if(publicationType!=null && publicationType.getSelectedValues()!=null) {
+			try {
+				String thePublicationTypeValue = publicationType.getSelectedValues().get(0);
+				LOG.debug("Set publication type: "+thePublicationTypeValue);
+				depositionMetadata.setPublication_type(PublicationType.valueOf(thePublicationTypeValue));
+			}catch (Exception e) {
+				LOG.warn("Set publication type error: ",e);
+			}
 		}
 		
 		//image type
 		SerializableEnum<String> imageType = metadata.getImage_type();
 		LOG.debug("Read image type: "+imageType);
-		if(imageType!=null) {
-			String imageTypeValue = imageType.getSelectedValues().get(0);
-			LOG.debug("Set image type: "+imageTypeValue);
-			depositionMetadata.setImage_type(ImageType.valueOf(imageTypeValue));
+		if(imageType!=null && imageType.getSelectedValues()!=null) {
+			try {
+				String imageTypeValue = imageType.getSelectedValues().get(0);
+				LOG.debug("Set image type: "+imageTypeValue);
+				depositionMetadata.setImage_type(ImageType.valueOf(imageTypeValue));
+			}catch (Exception e) {
+				LOG.warn("Set image type error: ",e);
+			}
 		}
 		
 		//embargo_date
 		Date embargoDate = metadata.getEmbargo_date();
 		LOG.debug("Read embargo date: "+imageType);
 		if(embargoDate!=null) {
-			LOG.debug("Set embargo date: "+embargoDate);
-			depositionMetadata.setEmbargo_date(embargoDate);
+			try {
+				LOG.debug("Set embargo date: "+embargoDate);
+				depositionMetadata.setEmbargo_date(embargoDate);
+			}catch (Exception e) {
+				LOG.warn("Set embargo date error: ",e);
+			}
 		}
 		
 		//access conditions
@@ -499,9 +516,13 @@ public class ItemToZenodoConverter {
 		SerializableEnum<LicenseBean> licenses = metadata.getLicenses();
 		LOG.debug("Read licenses: "+licenses);
 		if(licenses!=null) {
-			LicenseBean lB = licenses.getSelectedValues().get(0);
-			LOG.debug("Set license: "+lB);
-			depositionMetadata.setLicense(lB.getId());
+			try {
+				LicenseBean lB = licenses.getSelectedValues().get(0);
+				LOG.debug("Set license: "+lB);
+				depositionMetadata.setLicense(lB.getId());
+			}catch (Exception e) {
+				LOG.warn("Set license error: ",e);
+			}
 		}
 		
 		//creators
@@ -551,9 +572,15 @@ public class ItemToZenodoConverter {
 		for (ZenodoAuthor zenodoAuthor : zenodoCreators) {
 			Creator creator = new Creator();
 			creator.setName(zenodoAuthor.getName());
-			creator.setAffiliation(zenodoAuthor.getAffiliation());
-			creator.setGnd(zenodoAuthor.getGnd());
-			creator.setOrcid(zenodoAuthor.getOrcid());
+			if(CkanToZenodoUtil.isNotEmpty(zenodoAuthor.getAffiliation())) {
+				creator.setAffiliation(zenodoAuthor.getAffiliation());
+			}
+			if(CkanToZenodoUtil.isNotEmpty(zenodoAuthor.getGnd())) {
+				creator.setGnd(zenodoAuthor.getGnd());
+			}
+			if(CkanToZenodoUtil.isNotEmpty(zenodoAuthor.getOrcid())) {
+				creator.setOrcid(zenodoAuthor.getOrcid());
+			}
 			listOfCreators.add(creator);
 		}
 		
@@ -575,16 +602,22 @@ public class ItemToZenodoConverter {
 		for (ZenodoAuthor zenodoAuthor : zenodoContributors) {
 			Contributor contributor = new Contributor();
 			contributor.setName(zenodoAuthor.getName());
-			contributor.setAffiliation(zenodoAuthor.getAffiliation());
-			contributor.setGnd(zenodoAuthor.getGnd());
-			contributor.setOrcid(zenodoAuthor.getOrcid());
+			if(CkanToZenodoUtil.isNotEmpty(zenodoAuthor.getAffiliation())) {
+				contributor.setAffiliation(zenodoAuthor.getAffiliation());
+			}
+			if(CkanToZenodoUtil.isNotEmpty(zenodoAuthor.getGnd())) {
+				contributor.setGnd(zenodoAuthor.getGnd());
+			}
+			if(CkanToZenodoUtil.isNotEmpty(zenodoAuthor.getOrcid())) {
+				contributor.setOrcid(zenodoAuthor.getOrcid());
+			}
 			Type type = null;
 			String theType = null;
 			try {
 				theType = zenodoAuthor.getType().getSelectedValues().get(0);
 				type = Type.valueOf(theType);
 			}catch (Exception e) {
-				LOG.error("No able to convert "+theType + " as value of "+Type.class.getName());
+				LOG.error("I'm not able to convert "+theType + " as value of "+Type.class.getName());
 			}
 			contributor.setType(type);
 			listOfContributors.add(contributor);
